# HG changeset patch
# User StephaneLenclud
# Date 1453396575 -3600
# Node ID 533eb8a80d56b657f3f1695c202ca998323f6143
# Parent 9eb93d079a3ec64f5429ca7dda8d58ce61afe350
Server: Adding recording icon.
diff -r 9eb93d079a3e -r 533eb8a80d56 Server/Resources/record.ico
Binary file Server/Resources/record.ico has changed
diff -r 9eb93d079a3e -r 533eb8a80d56 Server/SharpDisplayManager.csproj
--- a/Server/SharpDisplayManager.csproj Thu Jan 21 15:00:05 2016 +0100
+++ b/Server/SharpDisplayManager.csproj Thu Jan 21 18:16:15 2016 +0100
@@ -85,7 +85,7 @@
false
- true
+ false
70A149AB9F89E507D9411D109553BE22455895D6
@@ -279,6 +279,7 @@
PreserveNewest
+
diff -r 9eb93d079a3e -r 533eb8a80d56 Server/MainForm.cs
--- a/Server/MainForm.cs Thu Jan 21 15:00:05 2016 +0100
+++ b/Server/MainForm.cs Thu Jan 21 18:16:15 2016 +0100
@@ -105,11 +105,17 @@
private StartupManager iStartupManager;
///
- /// System tray icon.
+ /// System notification icon used to hide our application from the task bar.
///
private SharpLib.Notification.Control iNotifyIcon;
///
+ /// System recording notifcation icon.
+ ///
+ private SharpLib.Notification.Control iRecordingNotification;
+
+
+ ///
/// Allow user to receive window messages;
///
public event WndProcDelegate OnWndProc;
@@ -129,8 +135,9 @@
iClients = new Dictionary();
iStartupManager = new StartupManager();
iNotifyIcon = new SharpLib.Notification.Control();
+ iRecordingNotification = new SharpLib.Notification.Control();
- //Have our designer initialize its controls
+ //Have our designer initialize its controls
InitializeComponent();
//Populate device types
@@ -193,8 +200,11 @@
//Setup notification icon
SetupTrayIcon();
- // To make sure start up with minimize to tray works
- if (WindowState == FormWindowState.Minimized && Properties.Settings.Default.MinimizeToTray)
+ //Setup recording notification
+ SetupRecordingNotification();
+
+ // To make sure start up with minimize to tray works
+ if (WindowState == FormWindowState.Minimized && Properties.Settings.Default.MinimizeToTray)
{
Visible = false;
}
@@ -579,6 +589,16 @@
}
///
+ ///
+ ///
+ private void SetupRecordingNotification()
+ {
+ iRecordingNotification.Icon = GetIcon("record.ico");
+ iRecordingNotification.Text = "No recording";
+ iRecordingNotification.Visible = true;
+ }
+
+ ///
/// Access icons from embedded resources.
///
///